/*
 * DynamicPlot.java
 *
 * Created on 23. mars 2007, 15:23
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package my.ABB_UI;

import java.awt.BasicStroke;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.Timer;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.DateAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.XYItemRenderer;
import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
import org.jfree.data.time.Millisecond;
import org.jfree.data.time.TimeSeries;
import org.jfree.data.time.TimeSeriesCollection;
import org.jfree.ui.RectangleInsets;

/**
 *
 * @author Erlend
 */
public class DynamicPlot extends JPanel{
    
    private ChartPanel panel;
    private TimeSeries serie;
    private JFreeChart freeChart;
    private String range_name;
    private double upper_bound;
    
    /** Creates a new instance of DynamicPlot 
     *
     */
    public DynamicPlot(String range_name, double upper_bound) {
              
        super(new BorderLayout());
       
        this.upper_bound = upper_bound;
        this.range_name = range_name;
        
        this.serie = new TimeSeries("et eller anna",Millisecond.class);
        this.serie.setMaximumItemAge(15000);
        
        TimeSeriesCollection dataset = new TimeSeriesCollection();
        dataset.addSeries(this.serie);
        
        XYItemRenderer renderer = new XYLineAndShapeRenderer(true, false);
        renderer.setSeriesPaint(0, Color.red);
        renderer.setStroke(new BasicStroke(1f, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
        
        DateAxis domain = new DateAxis("Time");
        NumberAxis range = new NumberAxis(range_name);
        domain.setTickLabelFont(new Font("SansSerif", Font.PLAIN, 8));
        range.setTickLabelFont(new Font("SansSerif", Font.PLAIN, 8));
        domain.setLabelFont(new Font("SansSerif", Font.PLAIN, 10));
        range.setLabelFont(new Font("SansSerif", Font.PLAIN, 10));
        
        XYPlot plot = new XYPlot(dataset, domain, range, renderer);
        plot.setDomainGridlinePaint(Color.lightGray);
        plot.setRangeGridlinePaint(Color.lightGray);
        plot.setAxisOffset(new RectangleInsets(5.0, 5.0, 5.0, 5.0));
        
        range.setAutoRange(false);
        range.setLowerBound(0.0);
        range.setUpperBound(upper_bound);
        
        domain.setAutoRange(true);
        domain.setLowerMargin(0.0);
        domain.setUpperMargin(0.0);
        domain.setTickLabelsVisible(true);
        
        range.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
        
        freeChart = new JFreeChart("", new Font("SansSerif", Font.BOLD, 0), plot, false);
        panel = new ChartPanel(freeChart);
        
        add(panel);
    }
    
    public ChartPanel getPanel(){
        return panel;
    }
    
    public JFreeChart getChart(){
        return freeChart;
    }
    
    public void addObservation(double y) {
        this.serie.add(new Millisecond(), y);
    }

   
    
    public void cleaObservations(){
        this.serie.clear();
    }
    
    
    
    
    
}
